==> scribes_0.3.2.9.orig.tar.gz: scribes-0.3.2.9/plugins/Lines/i18n.py <==
# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext
_ = gettext
msg0001 = _("Cannot perform operation in readonly mode")
msg0002 = _("Deleted line %d")
msg0003 = _("Joined line %d to line %d")
msg0004 = _("No more lines to join")
msg0005 = _("Freed line %d")
msg0006 = _("Deleted text from cursor to end of line %d")
msg0007 = _("Cursor is already at the end of line")
msg0008 = _("Deleted text from cursor to beginning of line %d")
msg0009 = _("Cursor is already at the beginning of line")
msg0010 = _("_Lines")
msg0011 = _("_Delete Line")
msg0012 = _("_Join Line")
msg0013 = _("Free Line _Above")
msg0014 = _("Free Line _Below")
msg0015 = _("Delete Cursor to Line _End")
msg0016 = _("Delete _Cursor to Line Begin")
msg0017 = _("Duplicated line")
msg0018 = _("D_uplicate line")

==> scribes_0.3.3.3.orig.tar.gz: scribes-0.3.3.3/plugins/Lines/i18n.py <==
# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("Cannot perform operation in readonly mode")
msg0002 = _("Deleted line %d")
msg0003 = _("Joined line %d to line %d")
msg0004 = _("No more lines to join")
msg0005 = _("Freed line %d")
msg0006 = _("Deleted text from cursor to end of line %d")
msg0007 = _("Cursor is already at the end of line")
msg0008 = _("Deleted text from cursor to beginning of line %d")
msg0009 = _("Cursor is already at the beginning of line")
msg0010 = _("_Lines")
msg0011 = _("_Delete Line")
msg0012 = _("_Join Line")
msg0013 = _("Free Line _Above")
msg0014 = _("Free Line _Below")
msg0015 = _("Delete Cursor to Line _End")
msg0016 = _("Delete _Cursor to Line Begin")
msg0017 = _("Duplicated line")
msg0018 = _("D_uplicate line")
